@@ -62,13 +62,11 @@ class JNIFrameWork:
 			"""%(configGiws().getExceptionFileName()+configGiws().getCPPHeaderExtension())
 		# Byte support
 		strHeader+="""
-		#ifndef _MSC_VER /* Defined anyway with Visual */
-		#if !defined(byte)
-		typedef signed char byte;
-		#else
-		#pragma message("Byte has been redefined elsewhere. Some problems can happen")
-		#endif
-		#endif
+        #if !defined(byte) | !defined(_MSC_VER) /* Defined anyway with Visual */
+                typedef signed char byte;
+        #else
+                #pragma message("Byte has been redefined elsewhere. Some problems can happen")
+        #endif
 		"""
 		return strHeader
 
@@ -191,14 +189,14 @@ class JNIFrameWork:
 		params=""
 
 		for parameter in method.getParameters():
-			if parameter.getType().isArray(): # It is an array
+			if parameter.getType().isArray() and not parameter.getType().isByteBufferBased(): # It is an array
 				params+="[" * parameter.getType().getDimensionArray()
 			params+=parameter.getType().getTypeSignature()
 
 		methodIdName=method.getUniqueNameOfTheMethod()
 		
 		signatureReturn=method.getReturn().getTypeSignature()
-		if method.getReturn().isArray(): # Returns an array ... 
+		if method.getReturn().isArray() and not method.getReturn().isByteBufferBased(): # Returns an array ... 
 			signatureReturn="["* method.getReturn().getDimensionArray() + signatureReturn
 		
                 if method.getModifier()=="static":
@@ -281,7 +279,11 @@ class JNIFrameWork:
 		#     define GIWSEXPORT __declspec(dllexport)
 		#   endif
 		# else
+		#   if __GNUC__ >= 4
+		#     define GIWSEXPORT __attribute__ ((visibility ("default")))
+		#   else
 		#     define GIWSEXPORT
+		#   endif
 		# endif
 		#endif
 		"""
