@@ -35,23 +35,18 @@
 # For more information, see the file COPYING
 
 from datatypes.dataGiws import dataGiws
+from datatypes.dataBufferGiws import dataBufferGiws
 from datatypes.dataFactoryGiws import dataFactoryGiws
 
-class parameterGiws(dataGiws):
+class parameterGiws():
 	__name=""
 	__type=""
 
 	def __init__(self, name, type):
-
 		myDataFactory=dataFactoryGiws()
 		self.__type=myDataFactory.create(type)
 		self.__name=name
 		
-#		if isinstance(type,dataGiws):
-#			self.__type=type
-#		else:
-#		raise Exception("The type must be a dataGiws object")
-
 	def getName(self):
 		return self.__name
 
@@ -63,10 +58,11 @@ class parameterGiws(dataGiws):
 	
 	def generateCXXHeader(self):
 		""" Generate the profil of the parameter """
-		str="""%s %s""" % (self.getType().getNativeType(), self.getName())
+		str="""%s %s""" % (self.getType().getNativeTypeWithConst(), self.getName())
 		if self.getType().isArray():
 			if self.getType().getDimensionArray() == 1:
 				str+=", int %sSize"%self.getName()
 			else:
 				str+=", int %sSize, int %sSizeCol"%(self.getName(),self.getName())
 		return str
+
